==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/MedianPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MedianPriceIndicatorStrategy } from "./MedianPriceIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MedianPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MedianPriceIndicator, _super);
    function MedianPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MedianPriceIndicator.prototype.get_zk = function () {
        return new MedianPriceIndicatorStrategy();
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "zk", {
        get: function () {
            return this.get_zk();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.prototype.get_zb = function () {
        return MedianPriceIndicator.$;
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.$t = markType(MedianPriceIndicator, 'MedianPriceIndicator', ItemwiseStrategyBasedIndicator.$);
    return MedianPriceIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MedianPriceIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/MedianPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MedianPriceIndicatorStrategy } from "./MedianPriceIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MedianPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MedianPriceIndicator, _super);
    function MedianPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MedianPriceIndicator.prototype.bj = function () {
        return new MedianPriceIndicator();
    };
    MedianPriceIndicator.prototype.get_acc = function () {
        return new MedianPriceIndicatorStrategy();
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "acc", {
        get: function () {
            return this.get_acc();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.prototype.get_ab3 = function () {
        return MedianPriceIndicator.$;
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.$t = markType(MedianPriceIndicator, 'MedianPriceIndicator', ItemwiseStrategyBasedIndicator.$);
    return MedianPriceIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MedianPriceIndicator };
